{% extends "simple_import/base.html" %}

{% block simple_import_page_title %}Import{% endblock %}

{% block simple_import_title %}Import{% endblock %}

{% block simple_import_form %}
<form enctype="multipart/form-data" action="" method="post">{% csrf_token %}
    <table>
        {{ form.as_table }}
    </table>
    <input type="submit"/>
</form>
{% endblock %}