<!DOCTYPE html>
<html>
<head lang="en">
  <meta charset="UTF-8">
  <title>{% block simple_import_page_title %}{% endblock %}
</title>
</head>
<body>
<h1>{% block simple_import_title %}{% endblock %}</h1>
{% block simple_import_form %}{% endblock %}
</body>
</html>